Package: mlr3filters
Title: Filter Based Feature Selection for 'mlr3'
Version: 0.9.1
Authors@R: c(
    person("Marc", "Becker", , "marcbecker@posteo.de", role = c("cre", "aut"),
        comment = c(ORCID = "0000-0002-8115-0400")),
    person("Patrick", "Schratz", , "patrick.schratz@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0003-0748-6624")),
    person("Michel", "Lang", , "michellang@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0001-9754-0393")),
    person("Bernd", "Bischl", , "bernd_bischl@gmx.net", role = "aut",
           comment = c(ORCID = "0000-0001-6002-6980")),
    person("Martin", "Binder", , "mlr.developer@mb706.com", role = "aut"),
    person("John", "Zobolas", , "bblodfon@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-3609-8674"))
  )
Description: Extends 'mlr3' with filter methods for feature selection.
    Besides standalone filter methods built-in methods of any
    machine-learning algorithm are supported.  Partial scoring of
    multivariate filter methods is supported.
License: LGPL-3
URL: https://mlr3filters.mlr-org.com,
        https://github.com/mlr-org/mlr3filters
BugReports: https://github.com/mlr-org/mlr3filters/issues
Depends: R (>= 3.1.0)
Imports: backports, checkmate, cli, data.table, mlr3 (>= 0.12.0),
        mlr3misc (>= 0.18.0), paradox, R6
Suggests: Boruta, care, caret, carSurv, FSelectorRcpp, knitr, lgr,
        mlr3learners, mlr3measures, mlr3pipelines, praznik, rpart,
        survival, testthat (>= 3.0.0), withr
Config/testthat/edition: 3
Encoding: UTF-8
NeedsCompilation: no
RoxygenNote: 7.3.3
Collate: 'Filter.R' 'mlr_filters.R' 'FilterAUC.R' 'FilterAnova.R'
        'FilterBoruta.R' 'FilterCMIM.R' 'FilterCarScore.R'
        'FilterCarSurvScore.R' 'FilterCorrelation.R' 'FilterDISR.R'
        'FilterFindCorrelation.R' 'FilterLearner.R'
        'FilterImportance.R' 'FilterInformationGain.R' 'FilterJMI.R'
        'FilterJMIM.R' 'FilterKruskalTest.R' 'FilterMIM.R'
        'FilterMRMR.R' 'FilterNJMIM.R' 'FilterPerformance.R'
        'FilterPermutation.R' 'FilterRelief.R'
        'FilterSelectedFeatures.R' 'FilterUnivariateCox.R'
        'FilterVariance.R' 'bibentries.R' 'flt.R' 'helper.R'
        'reexports.R' 'zzz.R'
Packaged: 2026-04-23 16:10:57 UTC; marc
Author: Marc Becker [cre, aut] (ORCID: <https://orcid.org/0000-0002-8115-0400>),
  Patrick Schratz [aut] (ORCID: <https://orcid.org/0000-0003-0748-6624>),
  Michel Lang [aut] (ORCID: <https://orcid.org/0000-0001-9754-0393>),
  Bernd Bischl [aut] (ORCID: <https://orcid.org/0000-0001-6002-6980>),
  Martin Binder [aut],
  John Zobolas [aut] (ORCID: <https://orcid.org/0000-0002-3609-8674>)
Maintainer: Marc Becker <marcbecker@posteo.de>
Repository: CRAN
Date/Publication: 2026-04-23 16:40:02 UTC
Built: R 4.5.2; ; 2026-04-24 13:25:57 UTC; unix
