# Generated by roxygen2: do not edit by hand

S3method(as.data.table,DictionaryFilter)
S3method(as.data.table,Filter)
export(Filter)
export(FilterAUC)
export(FilterAnova)
export(FilterBoruta)
export(FilterCMIM)
export(FilterCarScore)
export(FilterCarSurvScore)
export(FilterCorrelation)
export(FilterDISR)
export(FilterFindCorrelation)
export(FilterImportance)
export(FilterInformationGain)
export(FilterJMI)
export(FilterJMIM)
export(FilterKruskalTest)
export(FilterMIM)
export(FilterMRMR)
export(FilterNJMIM)
export(FilterPerformance)
export(FilterPermutation)
export(FilterRelief)
export(FilterSelectedFeatures)
export(FilterUnivariateCox)
export(FilterVariance)
export(as.data.table)
export(flt)
export(flts)
export(mlr_filters)
import(checkmate)
import(cli)
import(data.table)
import(mlr3)
import(mlr3misc)
import(paradox)
importFrom(R6,R6Class)
importFrom(data.table,as.data.table)
importFrom(stats,aov)
importFrom(stats,kruskal.test)
importFrom(stats,runif)
importFrom(stats,var)
importFrom(utils,bibentry)
importFrom(utils,head)
