#' @import data.table
#' @import checkmate
#' @import cli
#' @import paradox
#' @import mlr3misc
#' @import mlr3
#' @importFrom R6 R6Class
#' @importFrom utils head
"_PACKAGE"

#nolint next
.onLoad = function(libname, pkgname) {
  # nocov start
  backports::import(pkgname)
} # nocov end

leanify_package()
