#' @importFrom utils bibentry
bibentries = c(
  bommert_2020 = bibentry("article",
    doi        = "10.1016/j.csda.2019.106839",
    year       = "2020",
    month      = "3",
    publisher  = "Elsevier {BV}",
    volume     = "143",
    pages      = "106839",
    author     = "Andrea Bommert and Xudong Sun and Bernd Bischl and J\u00f6rg Rahnenf\u00fchrer and Michel Lang",
    title      = "Benchmark for filter methods for feature selection in high-dimensional classification data",
    journal    = "Computational Statistics & Data Analysis"
  ),

  kursa_2021 = bibentry("article",
    doi        = "10.1016/j.softx.2021.100819",
    year       = "2021",
    month      = "12",
    publisher  = "Elsevier {BV}",
    volume     = "16",
    pages      = "100819",
    author     = "Miron B. Kursa",
    title      = "Praznik: High performance information-based feature selection",
    journal    = "{SoftwareX}"
  ),

  bommert_2021 = bibentry("article",
    doi = "10.1093/bib/bbab354",
    year = "2021",
    month = "9",
    publisher = "Oxford University Press ({OUP})",
    volume = "23",
    number = "1",
    author = "Andrea Bommert and Thomas Welchowski and Matthias Schmid and J\u00f6rg Rahnenf\u00fchrer",
    title = "Benchmark of filter methods for feature selection in high-dimensional gene expression survival data",
    journal = "Briefings in Bioinformatics"
  ),

  kursa_2010 = bibentry("article",
    title = "Feature Selection with the Boruta Package",
    volume = "36",
    number = "11",
    journal = "Journal of Statistical Software",
    author = "Miron B. Kursa and Witold R. Rudnicki",
    year = "2010",
    pages = "1-13")
)
